<?php

/**
 * @file
 * Callbacks for copyscape settings pages.
 */

/**
 * Admin page callback for the API and Users Settings Page.
 */
function copyscape_admin_settings_api() {
  $form = array();

  $form['copyscape_api_url'] = array(
    '#type'          => 'textfield',
    '#title'         => t('API URL'),
    '#default_value' => variable_get('copyscape_api_url', COPYSCAPE_DEFAULT_API_URL),
    '#required'      => TRUE,
    '#description'   => t('The Copyscape Premium API URL to execute queries against.'),
  );

  $form['copyscape_api_username'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Username'),
    '#default_value' => variable_get('copyscape_api_username', ''),
    '#required'      => TRUE,
    '#description'   => t('The username to authenticate with Copyscape Premium API'),
  );

  $form['copyscape_api_key'] = array(
    '#type'          => 'textfield',
    '#title'         => t('API Key'),
    '#default_value' => variable_get('copyscape_api_key', ''),
    '#required'      => TRUE,
    '#description'   => t('The API key to authenticate with Copyscape Premium API. You can create one')
    . ' ' . '<a href="http://www.copyscape.com/signup.php?sign_up&pro=1" target="_blank">'
    . t('here') . '</a>',
  );

  $form['copyscape_users_bypass'] = array(
    '#type'          => 'textarea',
    '#title'         => t('Bypass User IDs'),
    '#default_value' => variable_get('copyscape_users_bypass', ''),
    '#cols'          => 60,
    '#rows'          => 5,
    '#description'   => t('A list of user IDs that bypass the copyscape content verification.'),
  );

  $form['copyscape_roles_bypass'] = array(
    '#type'          => 'checkboxes',
    '#title'         => t('Bypass Roles'),
    '#options'       => user_roles(),
    '#default_value' => variable_get('copyscape_roles_bypass', array()),
    '#description'   => t('Roles that bypass the copyscape content verification.'),
  );

  $form['copyscape_fails_number'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Maximum fails number before user is blocked'),
    '#default_value' => variable_get('copyscape_fails_number', 0),
    '#size'          => '60',
    '#maxlength'     => '5',
    '#description'   => t('0 = Disabled'),
  );

  return system_settings_form($form);
}

/**
 * Admin page callback for the Copyscape Content Settings page.
 */
function copyscape_admin_settings_content() {
  $form = array();

  $form['copyscape_reject_content'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Reject content if copy percentage is bigger then:'),
    '#default_value' => variable_get('copyscape_reject_content', FALSE),
  );

  $form['copyscape_percentage_copied_content'] = array(
    '#type'          => 'textfield',
    '#default_value' => variable_get('copyscape_percentage_copied_content'),
    '#field_suffix'  => '%',
    '#size'          => '60',
    '#maxlength'     => '3',
  );

  foreach (node_type_get_types() as $node_type_name => $node_type) {
    $form[$node_type_name] = array(
      '#type'        => 'fieldset',
      '#title'       => $node_type->name . ' ' . t('Content Type'),
      '#collapsible' => TRUE,
      '#collapsed'   => FALSE,
    );

    $fields = array();

    foreach (field_info_instances('node', $node_type_name) as $field_name => $field) {
      if (!in_array($field['widget']['type'], array(
        'text_textarea',
        'text_textarea_with_summary',
      ))) {
        continue;
      }

      $fields[$node_type_name . '_' . $field_name] = $field['label'];
    }

    $form[$node_type_name]['copyscape_' . $node_type_name . '_checkboxes'] = array(
      '#type'          => 'checkboxes',
      '#options'       => $fields,
      '#default_value' => variable_get('copyscape_' . $node_type_name . '_checkboxes', array()),
    );
  }

  return system_settings_form($form);
}
