<?php

/**
 * @file
 * Copyspace callbacks.
 */

/**
 * Menu callback for copyscape/results.
 *
 * @return array
 *   The rendered array containing Copyscape results themed for table display.
 */
function copyscape_results_list() {
  $query = db_select('copyscape_results', 'cp')->extend('PagerDefault')
    ->fields('cp', array('nid', 'response', 'created'))
    ->orderBy('created', 'DESC')
    ->limit(10);

  $results = $query->execute()
    ->fetchAssoc();

  if (empty($results)) {
    // No copyscape results in the database.
    return t('There are no copyscape results in the database at the moment.');
  }

  // Build the header.
  $header = array(t('Node ID'), t('Result'), t('Updated'));

  // Build the table fields.
  $rows = array();
  foreach ($results as $row) {
    $response = unserialize($row->response);

    if (empty($response['result'])) {
      $percentage = t('No results found');
    }
    else {
      $percentage = '';
      foreach ($response['result'] as $value) {
        if (!empty($value['percentmatched'])) {
          $percentage .= $value['url'] . ' ' . $value['percentmatched'] . '%<br />';
        }
      }

      $percentage = filter_xss($percentage);
    }

    $rows[] = array(
      $row->nid,
      $percentage,
      format_date($row->created, 'short'),
    );
  }

  return array(
    '#theme' => 'table',
    '#header' => $header,
    '#rows'   => $rows,
  );
}
